"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright 2017 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
const he = require("he");
const PopDownListPicker_1 = require("./gui/PopDownListPicker");
const CLASS_RESULT_GROUP_HEAD = "CLASS_RESULT_GROUP_HEAD";
const CLASS_RESULT_ICON_LEFT = "CLASS_RESULT_ICON_LEFT";
const CLASS_RESULT_ICON_RIGHT = "CLASS_RESULT_ICON_RIGHT";
const CLASS_RESULT_LABEL = "CLASS_RESULT_LABEL";
const CLASS_RESULT_SHORTCUT = "CLASS_RESULT_SHORTCUT";
function commandPaletteFilterEntries(entries, filter) {
    const lowerFilter = filter.toLowerCase();
    return entries.filter((entry) => entry.label.toLowerCase().includes(lowerFilter));
}
exports.commandPaletteFilterEntries = commandPaletteFilterEntries;
function commandPaletteFormatEntries(entries, selectedId, filterInputValue) {
    return (filterInputValue.trim() === "" ? commandPaletteFormatEntriesWithGroups : commandPaletteFormatEntriesAsList)(entries, selectedId);
}
exports.commandPaletteFormatEntries = commandPaletteFormatEntries;
function commandPaletteFormatEntriesAsList(entries, selectedId) {
    return entries.map((entry) => commandPaletteFormatEntry(entry, entry.id === selectedId)).join("");
}
function commandPaletteFormatEntriesWithGroups(entries, selectedId) {
    let currentGroup = null;
    const htmlParts = [];
    for (let entry of entries) {
        let extraClass = "";
        if (entry.group !== undefined && entry.group !== currentGroup && currentGroup !== null) {
            extraClass = CLASS_RESULT_GROUP_HEAD;
        }
        currentGroup = entry.group;
        htmlParts.push(commandPaletteFormatEntry(entry, entry.id === selectedId, extraClass));
    }
    return htmlParts.join("");
}
function commandPaletteFormatEntry(entry, selected, extraClassString = "") {
    return `<div class='${PopDownListPicker_1.PopDownListPicker.CLASS_RESULT_ENTRY} ${selected ? PopDownListPicker_1.PopDownListPicker.CLASS_RESULT_SELECTED : ""} ${extraClassString}' ${PopDownListPicker_1.PopDownListPicker.ATTR_DATA_ID}='${entry.id}'>
    <div class='${CLASS_RESULT_ICON_LEFT}'>${commandPaletteFormatIcon(entry.iconLeft)}</div>
    <div class='${CLASS_RESULT_ICON_RIGHT}'>${commandPaletteFormatIcon(entry.iconRight)}</div>
    <div class='${CLASS_RESULT_LABEL}'>${he.encode(entry.label)}</div>
    <div class='${CLASS_RESULT_SHORTCUT}'>${entry.shortcut !== undefined && entry.shortcut !== null ? he.encode(entry.shortcut) : ""}</div>
  </div>`;
}
function commandPaletteFormatIcon(iconName) {
    if (iconName != null && iconName.startsWith('extraicon-')) {
        return `<span class='fa fa-fw CLASS_EXTRAICON'>&${iconName.substr('extraicon-'.length)};</span>`;
    }
    else {
        return `<i class='fa fa-fw ${iconName !== undefined && iconName !== null ? "fa-" + iconName : ""}'></i>`;
    }
}
//# sourceMappingURL=CommandPaletteFunctions.js.map