"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ID = "EtCommandPlaceHolderTemplate";
let registered = false;
/**
 * An invisible element which can be placed in a terminal to mark the start of command output.
 */
class CommandPlaceHolder extends HTMLElement {
    /**
     * Initialize the EtCommandPlaceHolder class and resources.
     *
     * When EtCommandPlaceHolder is imported into a render process, this static
     * method must be called before an instances may be created. This is can be
     * safely called multiple times.
     */
    static init() {
        if (registered === false) {
            window.customElements.define(CommandPlaceHolder.TAG_NAME.toLowerCase(), CommandPlaceHolder);
            registered = true;
        }
    }
    /**
     * Type guard for detecting a EtCommandPlaceHolder instance.
     *
     * @param  node the node to test
     * @return      True if the node is a EtCommandPlaceHolder.
     */
    static is(node) {
        return node !== null && node !== undefined && node instanceof CommandPlaceHolder;
    }
    //-----------------------------------------------------------------------
    getMinHeight() {
        return 0;
    }
    getVirtualHeight(containerHeight) {
        return 0;
    }
    getReserveViewportHeight(containerHeight) {
        return 0;
    }
    setDimensionsAndScroll(setterState) {
    }
    markVisible(visible) {
    }
}
/**
 * The HTML tag name of this element.
 */
CommandPlaceHolder.TAG_NAME = "ET-COMMANDPLACEHOLDER";
CommandPlaceHolder.ATTR_COMMAND_LINE = "command-line";
exports.CommandPlaceHolder = CommandPlaceHolder;
//# sourceMappingURL=CommandPlaceholder.js.map