"use strict";
/*
 * Copyright 2014-2016 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const Logger_1 = require("./Logger");
/**
 * Decorator to log method calls.
 *
 * @param  {Object} target     [description]
 * @param  {string} key        [description]
 * @param  {any}    descriptor [description]
 * @return {[type]}            [description]
 */
function log(target, key, descriptor) {
    const originalMethod = descriptor.value;
    descriptor.value = function (...args) {
        var formatArgs = args.map(repr).join(", ");
        if ("_log" in this) {
            const logger = this._log;
            logger.debug(`\u2b9e Entering ${key}(${formatArgs})`);
            var result = originalMethod.apply(this, args);
            logger.debug(`\u2b9c Exiting ${key}(${formatArgs}) => ${repr(result)}`);
        }
        else {
            console.log(`\u2b9e Entering ${key}(${formatArgs})`);
            var result = originalMethod.apply(this, args);
            console.log(`\u2b9c Exiting ${key}(${formatArgs}) => ${repr(result)}`);
        }
        return result;
    };
    return descriptor;
}
exports.default = log;
function repr(obj) {
    if (obj === undefined) {
        return "undefined";
    }
    if (obj === null) {
        return "null";
    }
    const name = Logger_1.objectName(obj);
    if (name != null) {
        return name;
    }
    if (HTMLElement !== undefined) {
        if (obj instanceof HTMLElement) {
            return "<" + obj.tagName + ">";
        }
    }
    switch (typeof obj) {
        case "number":
            return "" + obj;
        case "string":
            return '"' + obj + '"';
        case "boolean":
            return "" + obj;
        default:
            return "object";
    }
}
//# sourceMappingURL=LogDecorator.js.map