"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright 2016 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
const DomUtils = require("./DomUtils");
const Logger_1 = require("./Logger");
const ElementResizeDetectorMaker = require("element-resize-detector");
let registered = false;
const ID = "ExtratermResizeCanaryTemplate";
const ID_SIZER = "ID_SIZER";
const ID_CONTAINER = "ID_CONTAINER";
class ResizeCanary extends HTMLElement {
    //-----------------------------------------------------------------------
    //
    //   #                                                         
    //   #       # ###### ######  ####  #   #  ####  #      ###### 
    //   #       # #      #      #    #  # #  #    # #      #      
    //   #       # #####  #####  #        #   #      #      #####  
    //   #       # #      #      #        #   #      #      #      
    //   #       # #      #      #    #   #   #    # #      #      
    //   ####### # #      ######  ####    #    ####  ###### ###### 
    //
    //-----------------------------------------------------------------------
    constructor() {
        super();
        this._initProperties();
    }
    static init() {
        if (registered === false) {
            window.customElements.define(ResizeCanary.TAG_NAME.toLowerCase(), ResizeCanary);
            registered = true;
        }
    }
    _initProperties() {
        this._log = Logger_1.getLogger(ResizeCanary.TAG_NAME, this);
        this._erd = null;
        this._laterHandle = null;
        this._css = "";
    }
    setCss(css) {
        this._css = css;
    }
    connectedCallback() {
        if (DomUtils.getShadowRoot(this) != null) {
            return;
        }
        const shadow = this.attachShadow({ mode: 'open', delegatesFocus: false });
        shadow.appendChild(this._createNodes());
        this._erd = ElementResizeDetectorMaker(); // Use the 'object' strategy, 'scroll' doesn't work here.
        const container = DomUtils.getShadowId(this, ID_SIZER);
        this._erd.listenTo(container, (el) => {
            if (this._laterHandle === null) {
                this._laterHandle = DomUtils.doLater(() => {
                    const event = new CustomEvent('resize', { detail: {} });
                    this.dispatchEvent(event);
                    this._laterHandle = null;
                }, 40);
            }
        });
    }
    _createNodes() {
        const div = window.document.createElement('div');
        div.innerHTML = `<style>
      #${ID_CONTAINER} {
        position: absolute;
        top: 0px;
        left: 0px;
        display: block;
        width: 1px;
        height: 1px;
        overflow: hidden;
      }
      
      #${ID_SIZER} {
        ${this._css}
      }
      </style>
` +
            `      <div id='${ID_CONTAINER}'>` +
            `<div id='${ID_SIZER}'>mmmmmlllll<br />mmmmmlllll<br />mmmmmlllll</div>` +
            `</div>`;
        ;
        const frag = window.document.createDocumentFragment();
        for (const kid of DomUtils.nodeListToArray(div.childNodes)) {
            frag.appendChild(kid);
        }
        return frag;
    }
}
ResizeCanary.TAG_NAME = "ET-RESIZE-CANARY";
exports.ResizeCanary = ResizeCanary;
//# sourceMappingURL=ResizeCanary.js.map