"use strict";
/*
 * Copyright 2014-2016 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const DomUtils = require("./DomUtils");
const ThemeConsumer = require("./ThemeConsumer");
const ResizeRefreshElementBase = require("./ResizeRefreshElementBase");
/**
 * A base class for HTMLElements which also want theming CSS support.
 */
class ThemeableElementBase extends ResizeRefreshElementBase.ResizeRefreshElementBase {
    /**
     * See `ThemeTypes.Themeable.setThemeCssMap()`
     */
    setThemeCssMap(cssMap) {
        if (DomUtils.getShadowRoot(this) === null) {
            return;
        }
        const themeElement = DomUtils.getShadowId(this, ThemeableElementBase.ID_THEME);
        if (themeElement === null) {
            return;
        }
        const cssText = this._themeCssFiles().map((cssFile) => cssMap.get(cssFile)).join("\n");
        themeElement.textContent = cssText;
    }
    /**
     * Custom Element 'connected' life cycle hook.
     */
    connectedCallback() {
        ThemeConsumer.registerThemeable(this);
    }
    /**
     * Custom Element 'detached' life cycle hook.
     */
    disconnectedCallback() {
        ThemeConsumer.unregisterThemeable(this);
    }
    /**
     * Updates the style element's CSS contents.
     */
    installThemeCss() {
        this.setThemeCssMap(ThemeConsumer.cssMap());
    }
    /**
     * Updates the Style element's CSS contents immediately and forces a refresh.
     */
    updateThemeCss() {
        this.installThemeCss();
        this.refresh(ResizeRefreshElementBase.RefreshLevel.COMPLETE);
    }
    /**
     * Gets the list of CssFiles this element requires for its CSS theming.
     *
     * Subclasses should override this method.
     *
     * @returns the list of CssFiles
     */
    _themeCssFiles() {
        return [];
    }
}
ThemeableElementBase.ID_THEME = "ID_THEME";
exports.ThemeableElementBase = ThemeableElementBase;
//# sourceMappingURL=ThemeableElementBase.js.map