"use strict";
/*
 * Copyright 2014-2016 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const ViewerElementTypes_1 = require("./ViewerElementTypes");
const ThemeableElementBase_1 = require("./ThemeableElementBase");
class ViewerElement extends ThemeableElementBase_1.ThemeableElementBase {
    /**
     * Type guard for detecting a ViewerElement instance.
     *
     * @param  node the node to test
     * @return      True if the node is a EtCodeMirrorViewer.
     */
    static isViewerElement(node) {
        return node !== null && node !== undefined && node instanceof ViewerElement;
    }
    getTitle() {
        return "ViewerElement";
    }
    hasFocus() {
        return false;
    }
    /**
     * Name of a Font Awesome icon to represent this viewer.
     */
    getAwesomeIcon() {
        return "desktop";
    }
    /**
     * Gets the selected text.
     *
     * @return the selected text or null if there is no selection.
     */
    getSelectionText() {
        return null;
    }
    clearSelection() {
    }
    isFocusable() {
        return false;
    }
    setFocusable(value) {
    }
    getVisualState() {
        return ViewerElementTypes_1.VisualState.AUTO;
    }
    setVisualState(state) {
    }
    getMode() {
        return ViewerElementTypes_1.Mode.DEFAULT;
    }
    setMode(mode) {
    }
    getText() {
        return null;
    }
    setText(text) {
    }
    getMimeType() {
        return null;
    }
    setMimeType(mimetype) {
    }
    getEditable() {
        return false;
    }
    setEditable(editable) {
    }
    // VirtualScrollable
    getMinHeight() {
        return 0;
    }
    // VirtualScrollable
    getVirtualHeight(containerHeight) {
        return 0;
    }
    // VirtualScrollable
    getReserveViewportHeight(containerHeight) {
        return 0;
    }
    // VirtualScrollable
    setDimensionsAndScroll(setterState) {
    }
    markVisible(visible) {
    }
    getCursorPosition() {
        return {
            left: 0,
            top: 0,
            bottom: 0,
            viewPortTop: 0
        };
    }
    setCursorPositionBottom(x) {
        return false;
    }
    setCursorPositionTop(x) {
        return false;
    }
    setBytes(buffer, mimeType) {
    }
}
ViewerElement.EVENT_BEFORE_SELECTION_CHANGE = "before-selection-change";
ViewerElement.EVENT_CURSOR_MOVE = "cursor-move";
ViewerElement.EVENT_CURSOR_EDGE = "cursor-edge";
exports.ViewerElement = ViewerElement;
//# sourceMappingURL=ViewerElement.js.map