"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright 2014-2016 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
const SourceMapSupport = require("source-map-support");
const VirtualScrollArea = require("./VirtualScrollArea");
SourceMapSupport.install();
class FakeScrollable {
    constructor(minHeight, virtualHeight, reserveViewportHeight) {
        this.minHeight = minHeight;
        this.virtualHeight = virtualHeight;
        this.reserveViewportHeight = reserveViewportHeight;
        this._offset = null;
        this._height = 10;
    }
    getMinHeight() {
        return this.minHeight;
    }
    setMinHeight(newMinHeight) {
        this.minHeight = newMinHeight;
    }
    getVirtualHeight(containerHeight) {
        return this.virtualHeight;
    }
    setVirtualHeight(newVirtualHeight) {
        this.virtualHeight = newVirtualHeight;
    }
    getReserveViewportHeight(containerHeight) {
        return this.reserveViewportHeight;
    }
    setReserveViewportHeight(newReserveViewportHeight) {
        this.reserveViewportHeight = newReserveViewportHeight;
    }
    setDimensionsAndScroll(setterState) {
        this._height = setterState.height;
        this._offset = setterState.yOffset;
    }
    markVisible(visible) {
    }
    getScrollOffset() {
        return this._offset;
    }
    getHeight() {
        return this._height;
    }
}
function SetUpScrollContainer(vsa, height) {
    const scrollContainer = {
        scrollTop: 0,
        getBoundingClientRect() {
            return { top: 0, bottom: 500, left: 0, right: 1024, height: height, width: 1024 };
        }
    };
    vsa.setScrollFunction((offset) => {
        scrollContainer.scrollTop = offset;
    });
    // vsa.setContainerHeightFunction( () => scrollContainer.getBoundingClientRect().height);
    return scrollContainer;
}
function SetupScrollable(vsa, minHeight, virtualHeight, reserveViewportHeight) {
    const scrollable = new FakeScrollable(minHeight, virtualHeight, reserveViewportHeight);
    vsa.appendScrollable(scrollable);
    return scrollable;
}
function SetupScrollbar(vsa) {
    let length = 123;
    let position = 7743;
    let thumbSize = 12;
    const scrollbar = {
        setLength: (len) => { length = len; },
        getLength: () => length,
        setPosition: (pos) => { position = pos; },
        getPosition: () => position,
        setThumbSize: (size) => { thumbSize = size; },
        getThumbSize: () => thumbSize
    };
    vsa.setScrollbar(scrollbar);
    return scrollbar;
}
//-------------------------------------------------------------------------
// #######                            
//    #    ######  ####  #####  ####  
//    #    #      #        #   #      
//    #    #####   ####    #    ####  
//    #    #           #   #        # 
//    #    #      #    #   #   #    # 
//    #    ######  ####    #    ####  
//-------------------------------------------------------------------------
function testBasic(test) {
    const vsa = new VirtualScrollArea.VirtualScrollArea();
    const scrollbar = SetupScrollbar(vsa);
    const scrollContainer = SetUpScrollContainer(vsa, 500);
    const scrollable = SetupScrollable(vsa, 500, 500, 0);
    vsa.updateContainerHeight(scrollContainer.getBoundingClientRect().height);
    test.equal(scrollbar.getPosition(), 0);
    test.equal(scrollable.getScrollOffset(), 0);
    test.done();
}
exports.testBasic = testBasic;
function testLong(test) {
    const vsa = new VirtualScrollArea.VirtualScrollArea();
    const scrollbar = SetupScrollbar(vsa);
    const container = SetUpScrollContainer(vsa, 500);
    const scrollable = SetupScrollable(vsa, 500, 1500, 0);
    vsa.updateContainerHeight(container.getBoundingClientRect().height);
    test.equal(scrollbar.getPosition(), 1000);
    test.equal(scrollbar.getLength(), 1500);
    test.equal(scrollable.getScrollOffset(), 1000);
    vsa.scrollTo(750);
    test.equal(scrollbar.getPosition(), 750);
    test.equal(container.scrollTop, 0);
    test.equal(scrollable.getScrollOffset(), 750);
    test.done();
}
exports.testLong = testLong;
function test3Scrollables(test) {
    const vsa = new VirtualScrollArea.VirtualScrollArea();
    const scrollbar = SetupScrollbar(vsa);
    const container = SetUpScrollContainer(vsa, 500);
    const scrollable1 = SetupScrollable(vsa, 500, 1500, 0);
    const scrollable2 = SetupScrollable(vsa, 500, 1500, 0);
    const scrollable3 = SetupScrollable(vsa, 500, 1500, 0);
    vsa.updateContainerHeight(container.getBoundingClientRect().height);
    test.equal(scrollbar.getPosition(), 4000);
    test.equal(scrollbar.getLength(), 4500);
    test.equal(scrollable1.getScrollOffset(), 1000);
    vsa.scrollTo(750);
    test.equal(scrollbar.getPosition(), 750);
    test.equal(container.scrollTop, 0);
    test.equal(scrollable1.getScrollOffset(), 750);
    test.equal(scrollable2.getScrollOffset(), 0);
    test.equal(scrollable3.getScrollOffset(), 0);
    vsa.scrollTo(1500);
    test.equal(scrollbar.getPosition(), 1500);
    test.equal(container.scrollTop, 500);
    test.equal(scrollable1.getScrollOffset(), 1000);
    test.equal(scrollable2.getScrollOffset(), 0);
    test.equal(scrollable3.getScrollOffset(), 0);
    vsa.scrollTo(2500);
    test.equal(scrollbar.getPosition(), 2500);
    test.equal(container.scrollTop, 500);
    test.equal(scrollable1.getScrollOffset(), 1000);
    test.equal(scrollable2.getScrollOffset(), 1000);
    test.equal(scrollable3.getScrollOffset(), 0);
    vsa.scrollTo(3500);
    test.equal(scrollbar.getPosition(), 3500);
    test.equal(container.scrollTop, 1000);
    test.equal(scrollable1.getScrollOffset(), 1000);
    test.equal(scrollable2.getScrollOffset(), 1000);
    test.equal(scrollable3.getScrollOffset(), 500);
    test.done();
}
exports.test3Scrollables = test3Scrollables;
function testVirtualHeightUpdate(test) {
    const vsa = new VirtualScrollArea.VirtualScrollArea();
    const scrollbar = SetupScrollbar(vsa);
    const container = SetUpScrollContainer(vsa, 500);
    const scrollable = SetupScrollable(vsa, 500, 1500, 0);
    vsa.updateContainerHeight(container.getBoundingClientRect().height);
    vsa.scrollTo(750);
    test.equal(scrollbar.getPosition(), 750);
    test.equal(container.scrollTop, 0);
    test.equal(scrollable.getScrollOffset(), 750);
    scrollable.setMinHeight(10);
    scrollable.setVirtualHeight(2000);
    scrollable.setReserveViewportHeight(0);
    vsa.updateScrollableSize(scrollable);
    test.equal(scrollbar.getPosition(), 750);
    test.equal(container.scrollTop, 0);
    test.equal(scrollable.getScrollOffset(), 750);
    test.done();
}
exports.testVirtualHeightUpdate = testVirtualHeightUpdate;
function testVirtualHeightUpdateAtBottom(test) {
    const vsa = new VirtualScrollArea.VirtualScrollArea();
    const scrollbar = SetupScrollbar(vsa);
    const container = SetUpScrollContainer(vsa, 500);
    const scrollable = SetupScrollable(vsa, 500, 1500, 0);
    vsa.updateContainerHeight(container.getBoundingClientRect().height);
    vsa.scrollTo(1000);
    test.equal(scrollbar.getPosition(), 1000);
    test.equal(container.scrollTop, 0);
    test.equal(scrollable.getScrollOffset(), 1000);
    scrollable.setMinHeight(10);
    scrollable.setVirtualHeight(2000);
    scrollable.setReserveViewportHeight(0);
    vsa.updateScrollableSize(scrollable);
    test.equal(scrollbar.getPosition(), 1500);
    test.equal(container.scrollTop, 0);
    test.equal(scrollable.getScrollOffset(), 1500);
    test.done();
}
exports.testVirtualHeightUpdateAtBottom = testVirtualHeightUpdateAtBottom;
function testShortWithReserve(test) {
    const vsa = new VirtualScrollArea.VirtualScrollArea();
    const scrollbar = SetupScrollbar(vsa);
    const container = SetUpScrollContainer(vsa, 1000);
    const scrollable = SetupScrollable(vsa, 500, 500, 200);
    vsa.updateContainerHeight(container.getBoundingClientRect().height);
    test.equal(scrollbar.getPosition(), 0);
    test.equal(scrollable.getHeight(), 700);
    test.equal(scrollable.getScrollOffset(), 0);
    test.equal(scrollbar.getLength(), 700);
    test.done();
}
exports.testShortWithReserve = testShortWithReserve;
function testHeightWithReserve(test) {
    const vsa = new VirtualScrollArea.VirtualScrollArea();
    const scrollbar = SetupScrollbar(vsa);
    const container = SetUpScrollContainer(vsa, 500);
    const scrollable = SetupScrollable(vsa, 500, 500, 200);
    vsa.updateContainerHeight(container.getBoundingClientRect().height);
    test.equal(scrollbar.getPosition(), 200);
    test.equal(scrollable.getScrollOffset(), 200);
    test.equal(scrollbar.getLength(), 700);
    test.done();
}
exports.testHeightWithReserve = testHeightWithReserve;
function testBottomWithReserve(test) {
    const vsa = new VirtualScrollArea.VirtualScrollArea();
    const scrollbar = SetupScrollbar(vsa);
    const container = SetUpScrollContainer(vsa, 500);
    const scrollable = SetupScrollable(vsa, 500, 500, 200);
    vsa.updateContainerHeight(container.getBoundingClientRect().height);
    vsa.scrollToBottom();
    test.equal(scrollbar.getPosition(), 200);
    test.equal(scrollable.getScrollOffset(), 200);
    test.equal(scrollbar.getLength(), 700);
    test.done();
}
exports.testBottomWithReserve = testBottomWithReserve;
function testBug(test) {
    const vsa = new VirtualScrollArea.VirtualScrollArea();
    const scrollbar = SetupScrollbar(vsa);
    const container = SetUpScrollContainer(vsa, 571);
    const scrollable1 = SetupScrollable(vsa, 0, 90, 0);
    const scrollable2 = SetupScrollable(vsa, 26, 0, 26);
    const scrollable3 = SetupScrollable(vsa, 0, 570, 0);
    vsa.updateContainerHeight(container.getBoundingClientRect().height);
    vsa.scrollTo(90);
    test.equal(scrollbar.getPosition(), 90);
    test.equal(container.scrollTop, 90);
    test.done();
}
exports.testBug = testBug;
function testBug2(test) {
    const vsa = new VirtualScrollArea.VirtualScrollArea();
    const scrollbar = SetupScrollbar(vsa);
    const container = SetUpScrollContainer(vsa, 571);
    // min, virtual, reserve
    const scrollable1 = SetupScrollable(vsa, 0, 90, 0);
    const scrollable2 = SetupScrollable(vsa, 26, 585, 26);
    const scrollable3 = SetupScrollable(vsa, 0, 15, 0);
    vsa.updateContainerHeight(container.getBoundingClientRect().height);
    vsa.scrollTo(145);
    test.equal(scrollbar.getPosition(), 145);
    test.equal(container.scrollTop, 105);
    test.done();
}
exports.testBug2 = testBug2;
//# sourceMappingURL=VirtualScrollAreaTest.js.map