"use strict";
/*
 * Copyright 2017 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
Object.defineProperty(exports, "__esModule", { value: true });
class OwnerTrackingList {
    constructor() {
        this._things = [];
    }
    add(owner, thing) {
        const pair = { owner, thing };
        this._things.push(pair);
        return { dispose: () => this._remove(pair) };
    }
    _remove(pair) {
        const index = this._things.indexOf(pair);
        if (index !== -1) {
            this._things.splice(index, 1);
        }
    }
    removeAllByOwner(owner) {
        this._things = this._things.filter(pair => pair.owner !== owner);
    }
    forEach(func) {
        this._things.forEach(pair => func(pair.thing));
    }
    map(func) {
        return this._things.map(pair => func(pair.thing));
    }
    mapWithOwner(func) {
        return this._things.map(pair => func(pair.owner, pair.thing));
    }
}
exports.default = OwnerTrackingList;
//# sourceMappingURL=OwnerTrackingList.js.map