/**
 * Copyright 2014-2015 Simon Edwards <simon@simonzone.com>
 */
"use strict";
const ViewerElement_1 = require("../ViewerElement");
const DomUtils = require("../DomUtils");
const markdownMod = require("markdown");
const markdown = markdownMod.markdown;
const ID = "EtMarkdownViewerTemplate";
const ID_CONTAINER = "container";
const ID_MAIN_STYLE = "main_style";
const ENCODING_ATTR = "encoding";
const ENCODING_PLAIN = "plain";
const ENCODING_BASE64 = "base64";
let registered = false;
class EtMarkdownViewer extends ViewerElement_1.ViewerElement {
    constructor() {
        super();
        this._initProperties();
        const shadow = this.attachShadow({ mode: 'open', delegatesFocus: false });
        const clone = this.createClone();
        shadow.appendChild(clone);
        this._updateFocusable(this._focusable);
        const containerDiv = DomUtils.getShadowId(this, ID_CONTAINER);
        containerDiv.addEventListener('keydown', (ev) => {
            if (ev.keyCode === 9 && !ev.ctrlKey) {
                ev.preventDefault();
            }
        });
    }
    static init() {
        if (registered === false) {
            window.customElements.define(EtMarkdownViewer.TAG_NAME.toLowerCase(), EtMarkdownViewer);
            registered = true;
        }
    }
    _initProperties() {
        this._focusable = false;
    }
    getAwesomeIcon() {
        return "file-text-o";
    }
    getSelectionText() {
        const root = DomUtils.getShadowRoot(this);
        const selection = root.getSelection();
        if (selection !== undefined && selection !== null && selection.rangeCount !== 0 &&
            !selection.getRangeAt(0).collapsed) {
            return selection.toString();
        }
        else {
            return null;
        }
    }
    focus() {
        DomUtils.getShadowId(this, ID_CONTAINER).focus();
    }
    hasFocus() {
        const root = DomUtils.getShadowRoot(this);
        return root.activeElement !== null;
    }
    isFocusable() {
        return this._focusable;
    }
    setFocusable(value) {
        this._focusable = value;
        this._updateFocusable(value);
    }
    connectedCallback() {
        super.connectedCallback();
        const container = DomUtils.getShadowId(this, ID_CONTAINER);
        const kids = this.childNodes;
        // Collect the raw text content.
        let text = "";
        let i = 0;
        for (i = 0; i < kids.length; i++) {
            if (kids[i].nodeName === '#text') {
                text = text + kids[i].textContent;
            }
        }
        const markdownText = markdown.toHTML(text);
        container.innerHTML = markdownText;
    }
    /**
     *
     */
    createClone() {
        let template = window.document.getElementById(ID);
        if (template === null) {
            template = window.document.createElement('template');
            template.id = ID;
            template.innerHTML = `<style id="${ID_MAIN_STYLE}">
        :host {
          display: block;
          width: 100%;
          white-space: normal;
        }
        
        #${ID_CONTAINER} {
          overflow: auto;
          height: 100%;
        }
        #${ID_CONTAINER}:focus {
          outline: 0px;
        }
        </style>
        <div id="${ID_CONTAINER}" class="markdown_viewer"></div>`;
            window.document.body.appendChild(template);
        }
        return window.document.importNode(template.content, true);
    }
    _updateFocusable(focusable) {
        const containerDiv = DomUtils.getShadowId(this, ID_CONTAINER);
        containerDiv.setAttribute('tabIndex', focusable ? "-1" : "");
    }
}
EtMarkdownViewer.TAG_NAME = "ET-MARKDOWN-VIEWER";
module.exports = EtMarkdownViewer;
//# sourceMappingURL=MarkdownViewer.js.map